@@ -4,7 +4,6 @@
 This module is used for data preproccessing
 '''
 import numpy as np
-from maysics.utils import e_distances
 from matplotlib import pyplot as plt
 plt.rcParams['font.sans-serif'] = ['FangSong']
 plt.rcParams['axes.unicode_minus'] = False
@@ -135,7 +134,7 @@ def preview_file(filename, data, value_round=3):
     ----
     filename：字符串类型，文件名
     data：二维数组，数据
-    value_round：整型，数字特征保留的小数点后的位数
+    value_round：整型，可选，数字特征保留的小数点后的位数，默认为3
     
     
     Generate preview report with html file
@@ -144,7 +143,7 @@ def preview_file(filename, data, value_round=3):
     ----------
     filename: str, file name
     data: 2D array, data
-    value_round: int, the number of digits after the decimal point retained by numeric features
+    value_round: int, callable, the number of digits after the decimal point retained by numeric features, default=3
     '''
     root = _preview_process(data=data, value_round=value_round)
     html = etree.HTML(root)
@@ -159,7 +158,7 @@ def preview(data, value_round=3):
     参数
     ----
     data：二维数组，数据
-    value_round：整型，数字特征保留的小数点后的位数
+    value_round：整型，可选，数字特征保留的小数点后的位数，默认为3
     
     
     Display preview report in jupyter
@@ -167,7 +166,7 @@ def preview(data, value_round=3):
     Parameters
     ----------
     data: 2D array, data
-    value_round: int, the number of digits after the decimal point retained by numeric features
+    value_round: int, callable, the number of digits after the decimal point retained by numeric features, defualt=3
     '''
     root = _preview_process(data=data, value_round=value_round)
     
@@ -500,7 +499,7 @@ def standard(data, mean=True, var=True, index=None):
     
     参数
     ----
-    data：2D的ndarray数据
+    data：二维ndarray数据
     mean：布尔类型或ndarray，可选，布尔类型决定是否将均值调整为0，ndarray用于设定不同的均值
     var：布尔类型或ndarray，可选，是否将方差调整为1，ndarray用于设定不同的方差
     index：列表类型，可选，需要进行标准化的列的索引，默认为全部
@@ -585,7 +584,7 @@ def minmax(data, feature_range=(0, 1), min_max=None, index=None):
     
     参数
     ----
-    data：2D的ndarray数据
+    data：二维ndarray数据
     feature_range：元组类型，可选，需要转换的范围，默认为(0, 1)
     min_max：元组类型，可选，用于设定最大最小值
     index：列表类型，可选，需要进行标准化的列的索引，默认为全部
@@ -610,7 +609,7 @@ def minmax(data, feature_range=(0, 1), min_max=None, index=None):
     ------
     tuple, (Normalized data, (miniment, maximent))
     '''
-    data=np.array(data, dtype=float)
+    data = np.array(data, dtype=float)
     
     if index:
         if not min_max:
@@ -629,21 +628,80 @@ def minmax(data, feature_range=(0, 1), min_max=None, index=None):
     return data, min_max
 
 
-def normalizer(data, index=None):
+def normalizer(data, index=None, norm=2):
     '''
-    使每个数据的模为1
+    正则化数据
     
     参数
     ----
-    data：2D的ndarray数据
+    data：二维ndarray数据
     index：列表形式，可选，需要进行标准化的列的索引，默认为全部
+    norm：整型或字符串类型，可选大于0的整数或'max'
+        当norm为整数p时，表示进行lp正则化；
+        当norm='max'时，表示使用最大范数进行正则化
     
     返回
     ----
     2D ndarray
     
     
-    Making the moduli of data equal 1
+    Normalize the data
+    
+    Parameters
+    ----------
+    data: 2D的ndarray数据
+    index: list, callable, index of columns need to be standardized, defalut to all
+    norm: int or str, callabel, an integer greater than 0 or 'max' are optional
+        When norm is an integer p, it means lp normalization
+        When norm='max', it means that the maximum norm is used for normalization
+    
+    Return
+    ------
+    2D ndarray
+    '''
+    data = np.array(data, dtype=float)
+    if norm != 'max':
+        if index:
+            distance_list = abs(data[:, index])**norm
+            distance_list = distance_list.sum(axis=1)
+            distance_list = distance_list**(1 / norm)
+            distance_list[distance_list == 0] = 1
+            data[:, index] /= np.array([distance_list]).T
+        
+        else:
+            distance_list = abs(data)**norm
+            distance_list = distance_list.sum(axis=1)
+            distance_list = distance_list**(1 / norm)
+            distance_list[distance_list == 0] = 1
+            data /= np.array([distance_list]).T
+    
+    elif norm == 'max':
+        if index:
+            data[:, index] /= np.array([abs(data[:, index]).max(axis=1)]).T
+        else:
+            data /= np.array([abs(data).max(axis=1)]).T
+    
+    else:
+        raise Exception("Wrong type of paramter 'norm'.")
+            
+    return data
+
+
+def onehot(data, index=None):
+    '''
+    将数据转换为one-hot编码
+    
+    参数
+    ----
+    data：二维ndarray数据
+    index：列表形式，可选，需要进行标准化的列的索引，默认为全部
+    
+    返回
+    ----
+    元组，(onehot编码数据, 名称列表)
+    
+    
+    Transform data to one-hot encoding
     
     Parameters
     ----------
@@ -652,21 +710,21 @@ def normalizer(data, index=None):
     
     Return
     ------
-    2D ndarray
+    tuple, (one-hot data, name list)
     '''
-    data = np.array(data, dtype=float)
+    if not index:
+        index = np.arange(data.shape[1]).tolist()
     
-    if index:
-        distance_list = e_distances(data[:, index])
-        distance_list[distance_list == 0] = 1
-        data[:, index] /= np.array([distance_list]).T
+    ls_all = []
+    for i in index[::-1]:
+        ls = list(set(data[:, i]))
+        ls_all.append(ls)
+        data_new = np.zeros((data.shape[0], len(ls)))
+        for j in range(len(ls)):
+            data_new[data[:, i] == ls[j], j] = 1
+        data = np.hstack((data[:, :i], data_new, data[:, i+1:]))
     
-    else:
-        distance_list = e_distances(data)
-        distance_list[distance_list == 0] = 1
-        data /= np.array([distance_list]).T
-    
-    return data
+    return data, ls_all[::-1]
 
 
 def pca(data, n=None, eig_vector=None):
@@ -676,7 +734,7 @@ def pca(data, n=None, eig_vector=None):
     参数
     ----
     data：二维数组，数据
-    n：整型或浮点数类型，可选，当n >= 1时，表示降至n维，当0< n < 1时，表示降维至累计方差贡献率 >= n，默认不降维
+    n：数类型，可选，当n >= 1时，表示降至n维，当0< n < 1时，表示降维至累计方差贡献率 >= n，默认不降维
     eig_vector：元组类型，可选，用于设定不同的特征向量，当设置该参数时，累计方差贡献率无意义，默认为None
     
     返回
@@ -689,7 +747,7 @@ def pca(data, n=None, eig_vector=None):
     Parameters
     ----------
     data：2D array, data
-    n: int or float, callable, when n > = 1, it means to reduce the dimension to n; when 0 < n < 1, it means to reduce the dimension to cumulative variance ratio > = n, and it is not reduced by default
+    n: num, callable, when n > = 1, it means to reduce the dimension to n; when 0 < n < 1, it means to reduce the dimension to cumulative variance ratio > = n, and it is not reduced by default
     eig_value_vector: tuple, callable, set different eigenvectors, when this parameter is set, the cumulative variance ratio is meaningless, default=None
     
     Return
