@@ -58,7 +58,7 @@ def lorentz(v, x):
     
     参数
     ----
-    v：惯性系的相对速度，当速度方向沿着x轴正方向时（正变换）v为正
+    v：数类型，惯性系的相对速度，当速度方向沿着x轴正方向时（正变换）v为正
     x：一维或二维列表，(x, y, z, t)
     
     返回
@@ -70,14 +70,14 @@ def lorentz(v, x):
     
     Parameters
     ----------
-    v: relative velocity of inertial system, 'v' is positive when the velocity direction is along the positive direction of x-axis (positive transformation)
+    v: num, relative velocity of inertial system, 'v' is positive when the velocity direction is along the positive direction of x-axis (positive transformation)
     x: 1-D or 2-D list, (x, y, z, t)
     
     Return
     ------
     ndarray, converted coordinates
     '''
-    x = np.array(x, dtype=np.float)
+    x = np.array(x, dtype=float)
     γ = 1 / (1 - (v / 299792458.0)**2)**0.5
     if len(x.shape) == 1:
         xp = γ * (x[0] - v * x[3])
@@ -98,7 +98,7 @@ def lorentz_v(v, vo):
     
     参数
     ----
-    v：惯性系的相对速度，当速度方向沿着x轴正方向时（正变换）v为正
+    v：数类型，惯性系的相对速度，当速度方向沿着x轴正方向时（正变换）v为正
     vo：一维或二维列表，(vx, vy, vz)
     
     返回
@@ -110,14 +110,14 @@ def lorentz_v(v, vo):
     
     Parameters
     ----------
-    v: relative velocity of inertial system, 'v' is positive when the velocity direction is along the positive direction of x-axis (positive transformation)
+    v: num, relative velocity of inertial system, 'v' is positive when the velocity direction is along the positive direction of x-axis (positive transformation)
     vo: 1-D or 2-D list, (vx, vy, vz)
     
     Return
     ------
     ndarray, converted velocity
     '''
-    vo = np.array(vo, dtype=np.float)
+    vo = np.array(vo, dtype=float)
     γ = 1 / (1 - (v / 299792458.0)**2)**0.5
     if len(vo.shape) == 1:
         factor = 1 - v * vo[0] / 299792458.0**2
@@ -157,7 +157,7 @@ def polar(x):
     ------
     ndarray, converted coordinates
     '''
-    x = np.array(x, dtype=np.float)
+    x = np.array(x, dtype=float)
     if len(x.shape) == 1:
         r = (x[0]**2 + x[1]**2)**0.5
         if x[0] == 0:
@@ -220,7 +220,7 @@ def ipolar(x):
     ------
     ndarray, converted coordinates
     '''
-    x=np.array(x, dtype=np.float)
+    x=np.array(x, dtype=float)
     if len(x.shape) == 1:
         x0 = x[0] * np.cos(x[1])
         x1 = x[0] * np.sin(x[1])
@@ -257,7 +257,7 @@ def sphere(x):
     ------
     ndarray, converted coordinates
     '''
-    x = np.array(x, dtype=np.float)
+    x = np.array(x, dtype=float)
     if len(x.shape) == 1:
         r = (x[0]**2 + x[1]**2 + x[2]**2)**0.5
         if r == 0:
@@ -323,7 +323,7 @@ def isphere(x):
     ------
     ndarray, converted coordinates
     '''
-    x = np.array(x)
+    x = np.array(x, dtype=float)
     if len(x.shape) == 1:
         x0 = x[0] * np.sin(x[2]) * np.cos(x[1])
         x1 = x[0] * np.sin(x[2]) * np.sin(x[1])
@@ -366,7 +366,7 @@ def rotate(theta, x):
     ------
     ndarray, converted coordinates
     '''
-    x = np.array(x, dtype=np.float)
+    x = np.array(x, dtype=float)
     if len(x.shape) == 1:
         x0 = np.cos(theta) * x[0] + np.sin(theta) * x[1]
         x1 = np.cos(theta) * x[1] - np.sin(theta) * x[0]
